@@ -180,7 +180,7 @@ static void usage(void)
 
 static void version(void)
 {
-    wprintf(L"lolcat version 1.4, (c) 2023 jaseg\n");
+    wprintf(L"lolcat version 1.5, (c) 2024 jaseg\n");
     exit(0);
 }
 
@@ -390,8 +390,11 @@ int main(int argc, char** argv)
                     if (c == '\n') {
                         l++;
                         i = 0;
+                        cc = -1;
                         if (invert) {
                             wprintf(L"\033[49m");
+                        } else {
+                            wprintf(L"\033[0m");
                         }
 
                     } else {
